@@ -6,9 +6,9 @@ Type annotations for codeguruprofiler service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_codeguruprofiler.type_defs import AddNotificationChannelsRequestTypeDef
+    from mypy_boto3_codeguruprofiler.type_defs import AddNotificationChannelsRequestRequestTypeDef
 
-    data: AddNotificationChannelsRequestTypeDef = {...}
+    data: AddNotificationChannelsRequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -37,80 +37,80 @@ else:
 
 
 __all__ = (
-    "AddNotificationChannelsRequestTypeDef",
-    "AddNotificationChannelsResponseResponseTypeDef",
+    "AddNotificationChannelsRequestRequestTypeDef",
+    "AddNotificationChannelsResponseTypeDef",
     "AgentConfigurationTypeDef",
     "AgentOrchestrationConfigTypeDef",
     "AggregatedProfileTimeTypeDef",
     "AnomalyInstanceTypeDef",
     "AnomalyTypeDef",
-    "BatchGetFrameMetricDataRequestTypeDef",
-    "BatchGetFrameMetricDataResponseResponseTypeDef",
+    "BatchGetFrameMetricDataRequestRequestTypeDef",
+    "BatchGetFrameMetricDataResponseTypeDef",
     "ChannelTypeDef",
-    "ConfigureAgentRequestTypeDef",
-    "ConfigureAgentResponseResponseTypeDef",
-    "CreateProfilingGroupRequestTypeDef",
-    "CreateProfilingGroupResponseResponseTypeDef",
-    "DeleteProfilingGroupRequestTypeDef",
-    "DescribeProfilingGroupRequestTypeDef",
-    "DescribeProfilingGroupResponseResponseTypeDef",
+    "ConfigureAgentRequestRequestTypeDef",
+    "ConfigureAgentResponseTypeDef",
+    "CreateProfilingGroupRequestRequestTypeDef",
+    "CreateProfilingGroupResponseTypeDef",
+    "DeleteProfilingGroupRequestRequestTypeDef",
+    "DescribeProfilingGroupRequestRequestTypeDef",
+    "DescribeProfilingGroupResponseTypeDef",
     "FindingsReportSummaryTypeDef",
     "FrameMetricDatumTypeDef",
     "FrameMetricTypeDef",
-    "GetFindingsReportAccountSummaryRequestTypeDef",
-    "GetFindingsReportAccountSummaryResponseResponseTypeDef",
-    "GetNotificationConfigurationRequestTypeDef",
-    "GetNotificationConfigurationResponseResponseTypeDef",
-    "GetPolicyRequestTypeDef",
-    "GetPolicyResponseResponseTypeDef",
-    "GetProfileRequestTypeDef",
-    "GetProfileResponseResponseTypeDef",
-    "GetRecommendationsRequestTypeDef",
-    "GetRecommendationsResponseResponseTypeDef",
-    "ListFindingsReportsRequestTypeDef",
-    "ListFindingsReportsResponseResponseTypeDef",
-    "ListProfileTimesRequestTypeDef",
-    "ListProfileTimesResponseResponseTypeDef",
-    "ListProfilingGroupsRequestTypeDef",
-    "ListProfilingGroupsResponseResponseTypeDef",
-    "ListTagsForResourceRequestTypeDef",
-    "ListTagsForResourceResponseResponseTypeDef",
+    "GetFindingsReportAccountSummaryRequestRequestTypeDef",
+    "GetFindingsReportAccountSummaryResponseTypeDef",
+    "GetNotificationConfigurationRequestRequestTypeDef",
+    "GetNotificationConfigurationResponseTypeDef",
+    "GetPolicyRequestRequestTypeDef",
+    "GetPolicyResponseTypeDef",
+    "GetProfileRequestRequestTypeDef",
+    "GetProfileResponseTypeDef",
+    "GetRecommendationsRequestRequestTypeDef",
+    "GetRecommendationsResponseTypeDef",
+    "ListFindingsReportsRequestRequestTypeDef",
+    "ListFindingsReportsResponseTypeDef",
+    "ListProfileTimesRequestRequestTypeDef",
+    "ListProfileTimesResponseTypeDef",
+    "ListProfilingGroupsRequestRequestTypeDef",
+    "ListProfilingGroupsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "MatchTypeDef",
     "MetricTypeDef",
     "NotificationConfigurationTypeDef",
     "PaginatorConfigTypeDef",
     "PatternTypeDef",
-    "PostAgentProfileRequestTypeDef",
+    "PostAgentProfileRequestRequestTypeDef",
     "ProfileTimeTypeDef",
     "ProfilingGroupDescriptionTypeDef",
     "ProfilingStatusTypeDef",
-    "PutPermissionRequestTypeDef",
-    "PutPermissionResponseResponseTypeDef",
+    "PutPermissionRequestRequestTypeDef",
+    "PutPermissionResponseTypeDef",
     "RecommendationTypeDef",
-    "RemoveNotificationChannelRequestTypeDef",
-    "RemoveNotificationChannelResponseResponseTypeDef",
-    "RemovePermissionRequestTypeDef",
-    "RemovePermissionResponseResponseTypeDef",
+    "RemoveNotificationChannelRequestRequestTypeDef",
+    "RemoveNotificationChannelResponseTypeDef",
+    "RemovePermissionRequestRequestTypeDef",
+    "RemovePermissionResponseTypeDef",
     "ResponseMetadataTypeDef",
-    "SubmitFeedbackRequestTypeDef",
-    "TagResourceRequestTypeDef",
+    "SubmitFeedbackRequestRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TimestampStructureTypeDef",
-    "UntagResourceRequestTypeDef",
-    "UpdateProfilingGroupRequestTypeDef",
-    "UpdateProfilingGroupResponseResponseTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateProfilingGroupRequestRequestTypeDef",
+    "UpdateProfilingGroupResponseTypeDef",
     "UserFeedbackTypeDef",
 )
 
-AddNotificationChannelsRequestTypeDef = TypedDict(
-    "AddNotificationChannelsRequestTypeDef",
+AddNotificationChannelsRequestRequestTypeDef = TypedDict(
+    "AddNotificationChannelsRequestRequestTypeDef",
     {
         "channels": List["ChannelTypeDef"],
         "profilingGroupName": str,
     },
 )
 
-AddNotificationChannelsResponseResponseTypeDef = TypedDict(
-    "AddNotificationChannelsResponseResponseTypeDef",
+AddNotificationChannelsResponseTypeDef = TypedDict(
+    "AddNotificationChannelsResponseTypeDef",
     {
         "notificationConfiguration": "NotificationConfigurationTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -185,14 +185,14 @@ AnomalyTypeDef = TypedDict(
     },
 )
 
-_RequiredBatchGetFrameMetricDataRequestTypeDef = TypedDict(
-    "_RequiredBatchGetFrameMetricDataRequestTypeDef",
+_RequiredBatchGetFrameMetricDataRequestRequestTypeDef = TypedDict(
+    "_RequiredBatchGetFrameMetricDataRequestRequestTypeDef",
     {
         "profilingGroupName": str,
     },
 )
-_OptionalBatchGetFrameMetricDataRequestTypeDef = TypedDict(
-    "_OptionalBatchGetFrameMetricDataRequestTypeDef",
+_OptionalBatchGetFrameMetricDataRequestRequestTypeDef = TypedDict(
+    "_OptionalBatchGetFrameMetricDataRequestRequestTypeDef",
     {
         "endTime": Union[datetime, str],
         "frameMetrics": List["FrameMetricTypeDef"],
@@ -204,14 +204,15 @@ _OptionalBatchGetFrameMetricDataRequestTypeDef = TypedDict(
 )
 
 
-class BatchGetFrameMetricDataRequestTypeDef(
-    _RequiredBatchGetFrameMetricDataRequestTypeDef, _OptionalBatchGetFrameMetricDataRequestTypeDef
+class BatchGetFrameMetricDataRequestRequestTypeDef(
+    _RequiredBatchGetFrameMetricDataRequestRequestTypeDef,
+    _OptionalBatchGetFrameMetricDataRequestRequestTypeDef,
 ):
     pass
 
 
-BatchGetFrameMetricDataResponseResponseTypeDef = TypedDict(
-    "BatchGetFrameMetricDataResponseResponseTypeDef",
+BatchGetFrameMetricDataResponseTypeDef = TypedDict(
+    "BatchGetFrameMetricDataResponseTypeDef",
     {
         "endTime": datetime,
         "endTimes": List["TimestampStructureTypeDef"],
@@ -243,14 +244,14 @@ class ChannelTypeDef(_RequiredChannelTypeDef, _OptionalChannelTypeDef):
     pass
 
 
-_RequiredConfigureAgentRequestTypeDef = TypedDict(
-    "_RequiredConfigureAgentRequestTypeDef",
+_RequiredConfigureAgentRequestRequestTypeDef = TypedDict(
+    "_RequiredConfigureAgentRequestRequestTypeDef",
     {
         "profilingGroupName": str,
     },
 )
-_OptionalConfigureAgentRequestTypeDef = TypedDict(
-    "_OptionalConfigureAgentRequestTypeDef",
+_OptionalConfigureAgentRequestRequestTypeDef = TypedDict(
+    "_OptionalConfigureAgentRequestRequestTypeDef",
     {
         "fleetInstanceId": str,
         "metadata": Dict[MetadataFieldType, str],
@@ -259,29 +260,29 @@ _OptionalConfigureAgentRequestTypeDef = TypedDict(
 )
 
 
-class ConfigureAgentRequestTypeDef(
-    _RequiredConfigureAgentRequestTypeDef, _OptionalConfigureAgentRequestTypeDef
+class ConfigureAgentRequestRequestTypeDef(
+    _RequiredConfigureAgentRequestRequestTypeDef, _OptionalConfigureAgentRequestRequestTypeDef
 ):
     pass
 
 
-ConfigureAgentResponseResponseTypeDef = TypedDict(
-    "ConfigureAgentResponseResponseTypeDef",
+ConfigureAgentResponseTypeDef = TypedDict(
+    "ConfigureAgentResponseTypeDef",
     {
         "configuration": "AgentConfigurationTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateProfilingGroupRequestTypeDef = TypedDict(
-    "_RequiredCreateProfilingGroupRequestTypeDef",
+_RequiredCreateProfilingGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateProfilingGroupRequestRequestTypeDef",
     {
         "clientToken": str,
         "profilingGroupName": str,
     },
 )
-_OptionalCreateProfilingGroupRequestTypeDef = TypedDict(
-    "_OptionalCreateProfilingGroupRequestTypeDef",
+_OptionalCreateProfilingGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateProfilingGroupRequestRequestTypeDef",
     {
         "agentOrchestrationConfig": "AgentOrchestrationConfigTypeDef",
         "computePlatform": ComputePlatformType,
@@ -291,36 +292,37 @@ _OptionalCreateProfilingGroupRequestTypeDef = TypedDict(
 )
 
 
-class CreateProfilingGroupRequestTypeDef(
-    _RequiredCreateProfilingGroupRequestTypeDef, _OptionalCreateProfilingGroupRequestTypeDef
+class CreateProfilingGroupRequestRequestTypeDef(
+    _RequiredCreateProfilingGroupRequestRequestTypeDef,
+    _OptionalCreateProfilingGroupRequestRequestTypeDef,
 ):
     pass
 
 
-CreateProfilingGroupResponseResponseTypeDef = TypedDict(
-    "CreateProfilingGroupResponseResponseTypeDef",
+CreateProfilingGroupResponseTypeDef = TypedDict(
+    "CreateProfilingGroupResponseTypeDef",
     {
         "profilingGroup": "ProfilingGroupDescriptionTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteProfilingGroupRequestTypeDef = TypedDict(
-    "DeleteProfilingGroupRequestTypeDef",
+DeleteProfilingGroupRequestRequestTypeDef = TypedDict(
+    "DeleteProfilingGroupRequestRequestTypeDef",
     {
         "profilingGroupName": str,
     },
 )
 
-DescribeProfilingGroupRequestTypeDef = TypedDict(
-    "DescribeProfilingGroupRequestTypeDef",
+DescribeProfilingGroupRequestRequestTypeDef = TypedDict(
+    "DescribeProfilingGroupRequestRequestTypeDef",
     {
         "profilingGroupName": str,
     },
 )
 
-DescribeProfilingGroupResponseResponseTypeDef = TypedDict(
-    "DescribeProfilingGroupResponseResponseTypeDef",
+DescribeProfilingGroupResponseTypeDef = TypedDict(
+    "DescribeProfilingGroupResponseTypeDef",
     {
         "profilingGroup": "ProfilingGroupDescriptionTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -356,8 +358,8 @@ FrameMetricTypeDef = TypedDict(
     },
 )
 
-GetFindingsReportAccountSummaryRequestTypeDef = TypedDict(
-    "GetFindingsReportAccountSummaryRequestTypeDef",
+GetFindingsReportAccountSummaryRequestRequestTypeDef = TypedDict(
+    "GetFindingsReportAccountSummaryRequestRequestTypeDef",
     {
         "dailyReportsOnly": bool,
         "maxResults": int,
@@ -366,8 +368,8 @@ GetFindingsReportAccountSummaryRequestTypeDef = TypedDict(
     total=False,
 )
 
-GetFindingsReportAccountSummaryResponseResponseTypeDef = TypedDict(
-    "GetFindingsReportAccountSummaryResponseResponseTypeDef",
+GetFindingsReportAccountSummaryResponseTypeDef = TypedDict(
+    "GetFindingsReportAccountSummaryResponseTypeDef",
     {
         "nextToken": str,
         "reportSummaries": List["FindingsReportSummaryTypeDef"],
@@ -375,30 +377,30 @@ GetFindingsReportAccountSummaryResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetNotificationConfigurationRequestTypeDef = TypedDict(
-    "GetNotificationConfigurationRequestTypeDef",
+GetNotificationConfigurationRequestRequestTypeDef = TypedDict(
+    "GetNotificationConfigurationRequestRequestTypeDef",
     {
         "profilingGroupName": str,
     },
 )
 
-GetNotificationConfigurationResponseResponseTypeDef = TypedDict(
-    "GetNotificationConfigurationResponseResponseTypeDef",
+GetNotificationConfigurationResponseTypeDef = TypedDict(
+    "GetNotificationConfigurationResponseTypeDef",
     {
         "notificationConfiguration": "NotificationConfigurationTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetPolicyRequestTypeDef = TypedDict(
-    "GetPolicyRequestTypeDef",
+GetPolicyRequestRequestTypeDef = TypedDict(
+    "GetPolicyRequestRequestTypeDef",
     {
         "profilingGroupName": str,
     },
 )
 
-GetPolicyResponseResponseTypeDef = TypedDict(
-    "GetPolicyResponseResponseTypeDef",
+GetPolicyResponseTypeDef = TypedDict(
+    "GetPolicyResponseTypeDef",
     {
         "policy": str,
         "revisionId": str,
@@ -406,14 +408,14 @@ GetPolicyResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetProfileRequestTypeDef = TypedDict(
-    "_RequiredGetProfileRequestTypeDef",
+_RequiredGetProfileRequestRequestTypeDef = TypedDict(
+    "_RequiredGetProfileRequestRequestTypeDef",
     {
         "profilingGroupName": str,
     },
 )
-_OptionalGetProfileRequestTypeDef = TypedDict(
-    "_OptionalGetProfileRequestTypeDef",
+_OptionalGetProfileRequestRequestTypeDef = TypedDict(
+    "_OptionalGetProfileRequestRequestTypeDef",
     {
         "accept": str,
         "endTime": Union[datetime, str],
@@ -425,14 +427,14 @@ _OptionalGetProfileRequestTypeDef = TypedDict(
 )
 
 
-class GetProfileRequestTypeDef(
-    _RequiredGetProfileRequestTypeDef, _OptionalGetProfileRequestTypeDef
+class GetProfileRequestRequestTypeDef(
+    _RequiredGetProfileRequestRequestTypeDef, _OptionalGetProfileRequestRequestTypeDef
 ):
     pass
 
 
-GetProfileResponseResponseTypeDef = TypedDict(
-    "GetProfileResponseResponseTypeDef",
+GetProfileResponseTypeDef = TypedDict(
+    "GetProfileResponseTypeDef",
     {
         "contentEncoding": str,
         "contentType": str,
@@ -441,16 +443,16 @@ GetProfileResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetRecommendationsRequestTypeDef = TypedDict(
-    "_RequiredGetRecommendationsRequestTypeDef",
+_RequiredGetRecommendationsRequestRequestTypeDef = TypedDict(
+    "_RequiredGetRecommendationsRequestRequestTypeDef",
     {
         "endTime": Union[datetime, str],
         "profilingGroupName": str,
         "startTime": Union[datetime, str],
     },
 )
-_OptionalGetRecommendationsRequestTypeDef = TypedDict(
-    "_OptionalGetRecommendationsRequestTypeDef",
+_OptionalGetRecommendationsRequestRequestTypeDef = TypedDict(
+    "_OptionalGetRecommendationsRequestRequestTypeDef",
     {
         "locale": str,
     },
@@ -458,14 +460,15 @@ _OptionalGetRecommendationsRequestTypeDef = TypedDict(
 )
 
 
-class GetRecommendationsRequestTypeDef(
-    _RequiredGetRecommendationsRequestTypeDef, _OptionalGetRecommendationsRequestTypeDef
+class GetRecommendationsRequestRequestTypeDef(
+    _RequiredGetRecommendationsRequestRequestTypeDef,
+    _OptionalGetRecommendationsRequestRequestTypeDef,
 ):
     pass
 
 
-GetRecommendationsResponseResponseTypeDef = TypedDict(
-    "GetRecommendationsResponseResponseTypeDef",
+GetRecommendationsResponseTypeDef = TypedDict(
+    "GetRecommendationsResponseTypeDef",
     {
         "anomalies": List["AnomalyTypeDef"],
         "profileEndTime": datetime,
@@ -476,16 +479,16 @@ GetRecommendationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListFindingsReportsRequestTypeDef = TypedDict(
-    "_RequiredListFindingsReportsRequestTypeDef",
+_RequiredListFindingsReportsRequestRequestTypeDef = TypedDict(
+    "_RequiredListFindingsReportsRequestRequestTypeDef",
     {
         "endTime": Union[datetime, str],
         "profilingGroupName": str,
         "startTime": Union[datetime, str],
     },
 )
-_OptionalListFindingsReportsRequestTypeDef = TypedDict(
-    "_OptionalListFindingsReportsRequestTypeDef",
+_OptionalListFindingsReportsRequestRequestTypeDef = TypedDict(
+    "_OptionalListFindingsReportsRequestRequestTypeDef",
     {
         "dailyReportsOnly": bool,
         "maxResults": int,
@@ -495,14 +498,15 @@ _OptionalListFindingsReportsRequestTypeDef = TypedDict(
 )
 
 
-class ListFindingsReportsRequestTypeDef(
-    _RequiredListFindingsReportsRequestTypeDef, _OptionalListFindingsReportsRequestTypeDef
+class ListFindingsReportsRequestRequestTypeDef(
+    _RequiredListFindingsReportsRequestRequestTypeDef,
+    _OptionalListFindingsReportsRequestRequestTypeDef,
 ):
     pass
 
 
-ListFindingsReportsResponseResponseTypeDef = TypedDict(
-    "ListFindingsReportsResponseResponseTypeDef",
+ListFindingsReportsResponseTypeDef = TypedDict(
+    "ListFindingsReportsResponseTypeDef",
     {
         "findingsReportSummaries": List["FindingsReportSummaryTypeDef"],
         "nextToken": str,
@@ -510,8 +514,8 @@ ListFindingsReportsResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListProfileTimesRequestTypeDef = TypedDict(
-    "_RequiredListProfileTimesRequestTypeDef",
+_RequiredListProfileTimesRequestRequestTypeDef = TypedDict(
+    "_RequiredListProfileTimesRequestRequestTypeDef",
     {
         "endTime": Union[datetime, str],
         "period": AggregationPeriodType,
@@ -519,8 +523,8 @@ _RequiredListProfileTimesRequestTypeDef = TypedDict(
         "startTime": Union[datetime, str],
     },
 )
-_OptionalListProfileTimesRequestTypeDef = TypedDict(
-    "_OptionalListProfileTimesRequestTypeDef",
+_OptionalListProfileTimesRequestRequestTypeDef = TypedDict(
+    "_OptionalListProfileTimesRequestRequestTypeDef",
     {
         "maxResults": int,
         "nextToken": str,
@@ -530,14 +534,14 @@ _OptionalListProfileTimesRequestTypeDef = TypedDict(
 )
 
 
-class ListProfileTimesRequestTypeDef(
-    _RequiredListProfileTimesRequestTypeDef, _OptionalListProfileTimesRequestTypeDef
+class ListProfileTimesRequestRequestTypeDef(
+    _RequiredListProfileTimesRequestRequestTypeDef, _OptionalListProfileTimesRequestRequestTypeDef
 ):
     pass
 
 
-ListProfileTimesResponseResponseTypeDef = TypedDict(
-    "ListProfileTimesResponseResponseTypeDef",
+ListProfileTimesResponseTypeDef = TypedDict(
+    "ListProfileTimesResponseTypeDef",
     {
         "nextToken": str,
         "profileTimes": List["ProfileTimeTypeDef"],
@@ -545,8 +549,8 @@ ListProfileTimesResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListProfilingGroupsRequestTypeDef = TypedDict(
-    "ListProfilingGroupsRequestTypeDef",
+ListProfilingGroupsRequestRequestTypeDef = TypedDict(
+    "ListProfilingGroupsRequestRequestTypeDef",
     {
         "includeDescription": bool,
         "maxResults": int,
@@ -555,8 +559,8 @@ ListProfilingGroupsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListProfilingGroupsResponseResponseTypeDef = TypedDict(
-    "ListProfilingGroupsResponseResponseTypeDef",
+ListProfilingGroupsResponseTypeDef = TypedDict(
+    "ListProfilingGroupsResponseTypeDef",
     {
         "nextToken": str,
         "profilingGroupNames": List[str],
@@ -565,15 +569,15 @@ ListProfilingGroupsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
     },
 )
 
-ListTagsForResourceResponseResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseResponseTypeDef",
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
     {
         "tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -631,16 +635,16 @@ PatternTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredPostAgentProfileRequestTypeDef = TypedDict(
-    "_RequiredPostAgentProfileRequestTypeDef",
+_RequiredPostAgentProfileRequestRequestTypeDef = TypedDict(
+    "_RequiredPostAgentProfileRequestRequestTypeDef",
     {
         "agentProfile": Union[bytes, IO[bytes], StreamingBody],
         "contentType": str,
         "profilingGroupName": str,
     },
 )
-_OptionalPostAgentProfileRequestTypeDef = TypedDict(
-    "_OptionalPostAgentProfileRequestTypeDef",
+_OptionalPostAgentProfileRequestRequestTypeDef = TypedDict(
+    "_OptionalPostAgentProfileRequestRequestTypeDef",
     {
         "profileToken": str,
     },
@@ -648,8 +652,8 @@ _OptionalPostAgentProfileRequestTypeDef = TypedDict(
 )
 
 
-class PostAgentProfileRequestTypeDef(
-    _RequiredPostAgentProfileRequestTypeDef, _OptionalPostAgentProfileRequestTypeDef
+class PostAgentProfileRequestRequestTypeDef(
+    _RequiredPostAgentProfileRequestRequestTypeDef, _OptionalPostAgentProfileRequestRequestTypeDef
 ):
     pass
 
@@ -687,16 +691,16 @@ ProfilingStatusTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredPutPermissionRequestTypeDef = TypedDict(
-    "_RequiredPutPermissionRequestTypeDef",
+_RequiredPutPermissionRequestRequestTypeDef = TypedDict(
+    "_RequiredPutPermissionRequestRequestTypeDef",
     {
         "actionGroup": Literal["agentPermissions"],
         "principals": List[str],
         "profilingGroupName": str,
     },
 )
-_OptionalPutPermissionRequestTypeDef = TypedDict(
-    "_OptionalPutPermissionRequestTypeDef",
+_OptionalPutPermissionRequestRequestTypeDef = TypedDict(
+    "_OptionalPutPermissionRequestRequestTypeDef",
     {
         "revisionId": str,
     },
@@ -704,14 +708,14 @@ _OptionalPutPermissionRequestTypeDef = TypedDict(
 )
 
 
-class PutPermissionRequestTypeDef(
-    _RequiredPutPermissionRequestTypeDef, _OptionalPutPermissionRequestTypeDef
+class PutPermissionRequestRequestTypeDef(
+    _RequiredPutPermissionRequestRequestTypeDef, _OptionalPutPermissionRequestRequestTypeDef
 ):
     pass
 
 
-PutPermissionResponseResponseTypeDef = TypedDict(
-    "PutPermissionResponseResponseTypeDef",
+PutPermissionResponseTypeDef = TypedDict(
+    "PutPermissionResponseTypeDef",
     {
         "policy": str,
         "revisionId": str,
@@ -731,24 +735,24 @@ RecommendationTypeDef = TypedDict(
     },
 )
 
-RemoveNotificationChannelRequestTypeDef = TypedDict(
-    "RemoveNotificationChannelRequestTypeDef",
+RemoveNotificationChannelRequestRequestTypeDef = TypedDict(
+    "RemoveNotificationChannelRequestRequestTypeDef",
     {
         "channelId": str,
         "profilingGroupName": str,
     },
 )
 
-RemoveNotificationChannelResponseResponseTypeDef = TypedDict(
-    "RemoveNotificationChannelResponseResponseTypeDef",
+RemoveNotificationChannelResponseTypeDef = TypedDict(
+    "RemoveNotificationChannelResponseTypeDef",
     {
         "notificationConfiguration": "NotificationConfigurationTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-RemovePermissionRequestTypeDef = TypedDict(
-    "RemovePermissionRequestTypeDef",
+RemovePermissionRequestRequestTypeDef = TypedDict(
+    "RemovePermissionRequestRequestTypeDef",
     {
         "actionGroup": Literal["agentPermissions"],
         "profilingGroupName": str,
@@ -756,8 +760,8 @@ RemovePermissionRequestTypeDef = TypedDict(
     },
 )
 
-RemovePermissionResponseResponseTypeDef = TypedDict(
-    "RemovePermissionResponseResponseTypeDef",
+RemovePermissionResponseTypeDef = TypedDict(
+    "RemovePermissionResponseTypeDef",
     {
         "policy": str,
         "revisionId": str,
@@ -776,16 +780,16 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredSubmitFeedbackRequestTypeDef = TypedDict(
-    "_RequiredSubmitFeedbackRequestTypeDef",
+_RequiredSubmitFeedbackRequestRequestTypeDef = TypedDict(
+    "_RequiredSubmitFeedbackRequestRequestTypeDef",
     {
         "anomalyInstanceId": str,
         "profilingGroupName": str,
         "type": FeedbackTypeType,
     },
 )
-_OptionalSubmitFeedbackRequestTypeDef = TypedDict(
-    "_OptionalSubmitFeedbackRequestTypeDef",
+_OptionalSubmitFeedbackRequestRequestTypeDef = TypedDict(
+    "_OptionalSubmitFeedbackRequestRequestTypeDef",
     {
         "comment": str,
     },
@@ -793,14 +797,14 @@ _OptionalSubmitFeedbackRequestTypeDef = TypedDict(
 )
 
 
-class SubmitFeedbackRequestTypeDef(
-    _RequiredSubmitFeedbackRequestTypeDef, _OptionalSubmitFeedbackRequestTypeDef
+class SubmitFeedbackRequestRequestTypeDef(
+    _RequiredSubmitFeedbackRequestRequestTypeDef, _OptionalSubmitFeedbackRequestRequestTypeDef
 ):
     pass
 
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
         "tags": Dict[str, str],
@@ -814,24 +818,24 @@ TimestampStructureTypeDef = TypedDict(
     },
 )
 
-UntagResourceRequestTypeDef = TypedDict(
-    "UntagResourceRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
         "tagKeys": List[str],
     },
 )
 
-UpdateProfilingGroupRequestTypeDef = TypedDict(
-    "UpdateProfilingGroupRequestTypeDef",
+UpdateProfilingGroupRequestRequestTypeDef = TypedDict(
+    "UpdateProfilingGroupRequestRequestTypeDef",
     {
         "agentOrchestrationConfig": "AgentOrchestrationConfigTypeDef",
         "profilingGroupName": str,
     },
 )
 
-UpdateProfilingGroupResponseResponseTypeDef = TypedDict(
-    "UpdateProfilingGroupResponseResponseTypeDef",
+UpdateProfilingGroupResponseTypeDef = TypedDict(
+    "UpdateProfilingGroupResponseTypeDef",
     {
         "profilingGroup": "ProfilingGroupDescriptionTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
